![logo](https://github.com/opengisch/pirogue/blob/master/pirogue.png?raw=true)

# pirogue
A tool to automatically create views and triggers on PostgreSQL databases

It supports both psycopg 2 and 3. One or the other is required.

Read the docs: https://opengisch.github.io/pirogue
